common

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Available

func Available(message string) metav1.Condition

Available returns a condition that indicates the resource being monitored is currently available

func Creating

func Creating() metav1.Condition

Creating returns a condition that indicates the resource being monitored is currently being created

func Error

func Error(message string) metav1.Condition

Error returns a condition that indicates a unspecified error has occurred

func ReadyFalse

func ReadyFalse(reason, message string) metav1.Condition

ReadyFalse returns a condition that indicates the resource is not ready due to an error

func ReadyTrue

func ReadyTrue(message string) metav1.Condition

ReadyTrue returns a condition that indicates the resource is ready and functioning correctly

func ReadyUnknown

func ReadyUnknown(reason, message string) metav1.Condition

ReadyUnknown returns a condition that indicates the resource readiness is unknown

func Unavailable

func Unavailable(message string) metav1.Condition

Unavailable returns a condition that indicates the resource being monitored is currently unavailable e.g. does the resource with the correct filter exist in the cluster?

func Updated

func Updated() metav1.Condition

Updated returns a condition that indicates the metric recently has been updated

Types

type APIKeyAuth added in v0.10.0

type APIKeyAuth struct {
	Token string
}

type CertificateAuth added in v0.10.0

type CertificateAuth struct {
	ClientCert []byte
	ClientKey  []byte
	CACert     []byte
}

type DataSinkCredentials

type DataSinkCredentials struct {
	Host string
	Path string

	// Token-based authentication
	APIKey *APIKeyAuth

	// Certificate-based authentication (mutual TLS)
	Certificate *CertificateAuth
}

DataSinkCredentials holds the credentials to access the data sink

Jump to