Documentation
¶
Index ¶
- func Available(message string) metav1.Condition
- func Creating() metav1.Condition
- func Error(message string) metav1.Condition
- func ReadyFalse(reason, message string) metav1.Condition
- func ReadyTrue(message string) metav1.Condition
- func ReadyUnknown(reason, message string) metav1.Condition
- func Unavailable(message string) metav1.Condition
- func Updated() metav1.Condition
- type APIKeyAuth
- type CertificateAuth
- type DataSinkCredentials
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Available ¶
Available returns a condition that indicates the resource being monitored is currently available
func Creating ¶
Creating returns a condition that indicates the resource being monitored is currently being created
func ReadyFalse ¶
ReadyFalse returns a condition that indicates the resource is not ready due to an error
func ReadyTrue ¶
ReadyTrue returns a condition that indicates the resource is ready and functioning correctly
func ReadyUnknown ¶
ReadyUnknown returns a condition that indicates the resource readiness is unknown
func Unavailable ¶
Unavailable returns a condition that indicates the resource being monitored is currently unavailable e.g. does the resource with the correct filter exist in the cluster?
Types ¶
type APIKeyAuth ¶ added in v0.10.0
type APIKeyAuth struct {
Token string
}
type CertificateAuth ¶ added in v0.10.0
type DataSinkCredentials ¶
type DataSinkCredentials struct {
Host string
Path string
// Token-based authentication
APIKey *APIKeyAuth
// Certificate-based authentication (mutual TLS)
Certificate *CertificateAuth
}
DataSinkCredentials holds the credentials to access the data sink